#include <iostream>
#include <cstdio>
#include <cmath>
#include <algorithm>
#include <vector>
#include "testlib.h"

using namespace std;

const int MAXN = (int)1e6 + 3;
const int INF = (int)1e6 + 3;

vector<int> A;
int N;


pair<int, int> p[4 * MAXN];
struct tree {

	void build(int v, int tl, int tr) {
		p[v] = {-INF, -INF};
		if (tl == tr) {
			p[v] = {-1, A[tl]};
			return;
		}
		int tm = (tl + tr) / 2;
		build(2 * v, tl, tm);
		build(2 * v + 1, tm + 1, tr);
	}

	void paint(int v, int tl, int tr, int l, int r, int c, int ind) {
		if (tl == l && tr == r) {
			p[v] = max(p[v], {ind, c});
		} else {
			int tm = (tl + tr) / 2;
			if (r <= tm) paint(2 * v, tl, tm, l, r, c, ind);
			else if (l > tm) paint(2 * v + 1, tm + 1, tr, l, r, c, ind);
			else {
				paint(2 * v, tl, tm, l, tm, c, ind);
				paint(2 * v + 1, tm + 1, tr, tm + 1, r, c, ind);
			}
		}
	}

	pair<int, int> get(int v, int tl, int tr, int pos) {
		if (tl == tr) {
			return p[v];
		}
		int tm = (tl + tr) / 2;
		if (pos <= tm) return max(get(2 * v, tl, tm, pos), p[v]);
		else return max(get(2 * v + 1, tm + 1, tr, pos), p[v]);
	}
} T;


struct segment {
	int l, r;

	segment() {}
	segment(int _l, int _r) {
		l = _l, r = _r;
	}

};

int checkAns(InStream& stream) {
	int ans = stream.readInt(-1, N, "answer");
	if (ans == -1) return ans;
	
	if (ans == 0) {
	    for (int i = 0; i + 1 < N; i++) {
	        if (A[i] > A[i + 1]) stream.quitf(_wa, "ans[%d] > ans[%d]", i + 1, i + 2);
	    }
	}
	vector<segment> seg;

	for (int i = 0; i < ans; i++) {
		int l = stream.readInt(1, N, "left index of segment");
		int r = stream.readInt(1, N, "right index of segment");
		if (l > r) stream.quitf(_wa, "left index of segment more than right");
		seg.emplace_back(l - 1, r - 1);
	}
	
	T.build(1, 0, N - 1);
	for (int i = 0; i < ans; i++) {
		int l = seg[i].l, r = seg[i].r;
	    int c = T.get(1, 0, N - 1, l).second;
		
	    if (c != T.get(1, 0, N - 1, r).second) {
			stream.quitf(_wa, "colors at %d and %d positions dont match", l + 1, r + 1);
		}
		T.paint(1, 0, N - 1, l, r, c, i);
	}

//	cout << "!!";
	int prev = -1;
	cout << ans << endl;
	for (int i = 0; i < N; i++) {
		int cur = T.get(1, 0, N - 1, i).second;
//		cout << '?' << cur << endl;
		
		if (prev > cur) stream.quitf(_wa, "ans[%d] > ans[%d]", i + 1, i + 2);
		prev = cur;
	}

	return ans;
}

int main(int argc, char *argv[]) {
	registerTestlibCmd(argc, argv);

	N = inf.readInt();
	
	A.resize(N + 1);
	for (int i = 0; i < N; i++) {
		A[i] = inf.readInt();
	}

//	cout << "!";
	int j = checkAns(ans), p = checkAns(ouf);
	if (j == -1 && p != -1) quitf(_fail, "participant has correct solution");
	if (j != -1 && p == -1) quitf(_wa, "participant's answer in the first line is -1 but solution exists");
	if (j > p) quitf(_fail, "participant has better answer: %d", p);
	if (p > j) quitf(_wa, "jury has better answer: %d", j);
	quitf(_ok, "%d lines", 2);
	return 0;
}